==> tv_8.2201-2509122314.zip: dyn/ru/bitel/bgbilling/modules/tv/dyn/cti/tve/ws/pricing/ObjectFactory.java <==

package ru.bitel.bgbilling.modules.tv.dyn.cti.tve.ws.pricing;

import javax.xml.bind.JAXBElement;
import javax.xml.bind.annotation.XmlElementDecl;
import javax.xml.bind.annotation.XmlRegistry;
import javax.xml.namespace.QName;


/**
 * This object contains factory methods for each 
 * Java content interface and Java element interface 
 * generated in the ru.bitel.bgbilling.modules.tv.dyn.cti.tve.ws.pricing package. 
 * <p>An ObjectFactory allows you to programatically 
 * construct new instances of the Java representation 
 * for XML content. The Java representation of XML 
 * content can consist of schema derived interfaces 
 * and classes representing the binding of schema 
 * type definitions, element declarations and model 
 * groups.  Factory methods for each of these are 
 * provided in this class.
 * 
 */
@XmlRegistry
public class ObjectFactory {

    private final static QName _BillingException_QNAME = new QName("http://ws.external.push.adapter.billing.integration.iptv.oss.cti.ru/", "BillingException");
    private final static QName _FindOfferingByIdResponse_QNAME = new QName("http://ws.external.push.adapter.billing.integration.iptv.oss.cti.ru/", "findOfferingByIdResponse");
    private final static QName _QueryOfferingsResponse_QNAME = new QName("http://ws.external.push.adapter.billing.integration.iptv.oss.cti.ru/", "queryOfferingsResponse");
    private final static QName _FindOfferingById_QNAME = new QName("http://ws.external.push.adapter.billing.integration.iptv.oss.cti.ru/", "findOfferingById");
    private final static QName _QueryOfferings_QNAME = new QName("http://ws.external.push.adapter.billing.integration.iptv.oss.cti.ru/", "queryOfferings");

    /**
     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: ru.bitel.bgbilling.modules.tv.dyn.cti.tve.ws.pricing
     * 
     */
    public ObjectFactory() {
    }

    /**
     * Create an instance of {@link Service }
     * 
     */
    public Service createService() {
        return new Service();
    }

    /**
     * Create an instance of {@link Service.AdditionalParameters }
     * 
     */
    public Service.AdditionalParameters createServiceAdditionalParameters() {
        return new Service.AdditionalParameters();
    }

    /**
     * Create an instance of {@link BillingException }
     * 
     */
    public BillingException createBillingException() {
        return new BillingException();
    }

    /**
     * Create an instance of {@link FindOfferingByIdResponse }
     * 
     */
    public FindOfferingByIdResponse createFindOfferingByIdResponse() {
        return new FindOfferingByIdResponse();
    }

    /**
     * Create an instance of {@link QueryOfferingsResponse }
     * 
     */
    public QueryOfferingsResponse createQueryOfferingsResponse() {
        return new QueryOfferingsResponse();
    }

    /**
     * Create an instance of {@link QueryOfferings }
     * 
     */
    public QueryOfferings createQueryOfferings() {
        return new QueryOfferings();
    }

    /**
     * Create an instance of {@link FindOfferingById }
     * 
     */
    public FindOfferingById createFindOfferingById() {
        return new FindOfferingById();
    }

    /**
     * Create an instance of {@link Price }
     * 
     */
    public Price createPrice() {
        return new Price();
    }

    /**
     * Create an instance of {@link Resource }
     * 
     */
    public Resource createResource() {
        return new Resource();
    }

    /**
     * Create an instance of {@link Interaction }
     * 
     */
    public Interaction createInteraction() {
        return new Interaction();
    }

    /**
     * Create an instance of {@link ServiceOffering }
     * 
     */
    public ServiceOffering createServiceOffering() {
        return new ServiceOffering();
    }

    /**
     * Create an instance of {@link TimeFrame }
     * 
     */
    public TimeFrame createTimeFrame() {
        return new TimeFrame();
    }

    /**
     * Create an instance of {@link ServiceSpecification }
     * 
     */
    public ServiceSpecification createServiceSpecification() {
        return new ServiceSpecification();
    }

    /**
     * Create an instance of {@link Service.AdditionalParameters.Entry }
     * 
     */
    public Service.AdditionalParameters.Entry createServiceAdditionalParametersEntry() {
        return new Service.AdditionalParameters.Entry();
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link BillingException }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.external.push.adapter.billing.integration.iptv.oss.cti.ru/", name = "BillingException")
    public JAXBElement<BillingException> createBillingException(BillingException value) {
        return new JAXBElement<BillingException>(_BillingException_QNAME, BillingException.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link FindOfferingByIdResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.external.push.adapter.billing.integration.iptv.oss.cti.ru/", name = "findOfferingByIdResponse")
    public JAXBElement<FindOfferingByIdResponse> createFindOfferingByIdResponse(FindOfferingByIdResponse value) {
        return new JAXBElement<FindOfferingByIdResponse>(_FindOfferingByIdResponse_QNAME, FindOfferingByIdResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link QueryOfferingsResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.external.push.adapter.billing.integration.iptv.oss.cti.ru/", name = "queryOfferingsResponse")
    public JAXBElement<QueryOfferingsResponse> createQueryOfferingsResponse(QueryOfferingsResponse value) {
        return new JAXBElement<QueryOfferingsResponse>(_QueryOfferingsResponse_QNAME, QueryOfferingsResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link FindOfferingById }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.external.push.adapter.billing.integration.iptv.oss.cti.ru/", name = "findOfferingById")
    public JAXBElement<FindOfferingById> createFindOfferingById(FindOfferingById value) {
        return new JAXBElement<FindOfferingById>(_FindOfferingById_QNAME, FindOfferingById.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link QueryOfferings }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.external.push.adapter.billing.integration.iptv.oss.cti.ru/", name = "queryOfferings")
    public JAXBElement<QueryOfferings> createQueryOfferings(QueryOfferings value) {
        return new JAXBElement<QueryOfferings>(_QueryOfferings_QNAME, QueryOfferings.class, null, value);
    }

}

==> tv_10.2507-2601090437.zip: dyn/ru/bitel/bgbilling/modules/tv/dyn/cti/tve/ws/pricing/ObjectFactory.java <==

package ru.bitel.bgbilling.modules.tv.dyn.cti.tve.ws.pricing;

import jakarta.xml.bind.JAXBElement;
import jakarta.xml.bind.annotation.XmlElementDecl;
import jakarta.xml.bind.annotation.XmlRegistry;
import javax.xml.namespace.QName;


/**
 * This object contains factory methods for each 
 * Java content interface and Java element interface 
 * generated in the ru.bitel.bgbilling.modules.tv.dyn.cti.tve.ws.pricing package. 
 * <p>An ObjectFactory allows you to programatically 
 * construct new instances of the Java representation 
 * for XML content. The Java representation of XML 
 * content can consist of schema derived interfaces 
 * and classes representing the binding of schema 
 * type definitions, element declarations and model 
 * groups.  Factory methods for each of these are 
 * provided in this class.
 * 
 */
@XmlRegistry
public class ObjectFactory {

    private final static QName _BillingException_QNAME = new QName("http://ws.external.push.adapter.billing.integration.iptv.oss.cti.ru/", "BillingException");
    private final static QName _FindOfferingByIdResponse_QNAME = new QName("http://ws.external.push.adapter.billing.integration.iptv.oss.cti.ru/", "findOfferingByIdResponse");
    private final static QName _QueryOfferingsResponse_QNAME = new QName("http://ws.external.push.adapter.billing.integration.iptv.oss.cti.ru/", "queryOfferingsResponse");
    private final static QName _FindOfferingById_QNAME = new QName("http://ws.external.push.adapter.billing.integration.iptv.oss.cti.ru/", "findOfferingById");
    private final static QName _QueryOfferings_QNAME = new QName("http://ws.external.push.adapter.billing.integration.iptv.oss.cti.ru/", "queryOfferings");

    /**
     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: ru.bitel.bgbilling.modules.tv.dyn.cti.tve.ws.pricing
     * 
     */
    public ObjectFactory() {
    }

    /**
     * Create an instance of {@link Service }
     * 
     */
    public Service createService() {
        return new Service();
    }

    /**
     * Create an instance of {@link Service.AdditionalParameters }
     * 
     */
    public Service.AdditionalParameters createServiceAdditionalParameters() {
        return new Service.AdditionalParameters();
    }

    /**
     * Create an instance of {@link BillingException }
     * 
     */
    public BillingException createBillingException() {
        return new BillingException();
    }

    /**
     * Create an instance of {@link FindOfferingByIdResponse }
     * 
     */
    public FindOfferingByIdResponse createFindOfferingByIdResponse() {
        return new FindOfferingByIdResponse();
    }

    /**
     * Create an instance of {@link QueryOfferingsResponse }
     * 
     */
    public QueryOfferingsResponse createQueryOfferingsResponse() {
        return new QueryOfferingsResponse();
    }

    /**
     * Create an instance of {@link QueryOfferings }
     * 
     */
    public QueryOfferings createQueryOfferings() {
        return new QueryOfferings();
    }

    /**
     * Create an instance of {@link FindOfferingById }
     * 
     */
    public FindOfferingById createFindOfferingById() {
        return new FindOfferingById();
    }

    /**
     * Create an instance of {@link Price }
     * 
     */
    public Price createPrice() {
        return new Price();
    }

    /**
     * Create an instance of {@link Resource }
     * 
     */
    public Resource createResource() {
        return new Resource();
    }

    /**
     * Create an instance of {@link Interaction }
     * 
     */
    public Interaction createInteraction() {
        return new Interaction();
    }

    /**
     * Create an instance of {@link ServiceOffering }
     * 
     */
    public ServiceOffering createServiceOffering() {
        return new ServiceOffering();
    }

    /**
     * Create an instance of {@link TimeFrame }
     * 
     */
    public TimeFrame createTimeFrame() {
        return new TimeFrame();
    }

    /**
     * Create an instance of {@link ServiceSpecification }
     * 
     */
    public ServiceSpecification createServiceSpecification() {
        return new ServiceSpecification();
    }

    /**
     * Create an instance of {@link Service.AdditionalParameters.Entry }
     * 
     */
    public Service.AdditionalParameters.Entry createServiceAdditionalParametersEntry() {
        return new Service.AdditionalParameters.Entry();
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link BillingException }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.external.push.adapter.billing.integration.iptv.oss.cti.ru/", name = "BillingException")
    public JAXBElement<BillingException> createBillingException(BillingException value) {
        return new JAXBElement<BillingException>(_BillingException_QNAME, BillingException.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link FindOfferingByIdResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.external.push.adapter.billing.integration.iptv.oss.cti.ru/", name = "findOfferingByIdResponse")
    public JAXBElement<FindOfferingByIdResponse> createFindOfferingByIdResponse(FindOfferingByIdResponse value) {
        return new JAXBElement<FindOfferingByIdResponse>(_FindOfferingByIdResponse_QNAME, FindOfferingByIdResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link QueryOfferingsResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.external.push.adapter.billing.integration.iptv.oss.cti.ru/", name = "queryOfferingsResponse")
    public JAXBElement<QueryOfferingsResponse> createQueryOfferingsResponse(QueryOfferingsResponse value) {
        return new JAXBElement<QueryOfferingsResponse>(_QueryOfferingsResponse_QNAME, QueryOfferingsResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link FindOfferingById }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.external.push.adapter.billing.integration.iptv.oss.cti.ru/", name = "findOfferingById")
    public JAXBElement<FindOfferingById> createFindOfferingById(FindOfferingById value) {
        return new JAXBElement<FindOfferingById>(_FindOfferingById_QNAME, FindOfferingById.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link QueryOfferings }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.external.push.adapter.billing.integration.iptv.oss.cti.ru/", name = "queryOfferings")
    public JAXBElement<QueryOfferings> createQueryOfferings(QueryOfferings value) {
        return new JAXBElement<QueryOfferings>(_QueryOfferings_QNAME, QueryOfferings.class, null, value);
    }

}
